==> mighttpd2-4.0.3-323-x86_64.pkg.tar.zst: usr/share/haskell/register/mighttpd2.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 mighttpd2
version:              4.0.3
visibility:           public
id:                   mighttpd2-4.0.3-AVhNDiUT1EPDmWRHoMGzfH
key:                  mighttpd2-4.0.3-AVhNDiUT1EPDmWRHoMGzfH
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
homepage:             https://kazu-yamamoto.github.io/mighttpd2/
synopsis:             High performance web server on WAI/warp
description:
    High performance web server to handle static
    files and CGI on WAI/warp.
    Reverse proxy functionality is also provided
    to connect web applications behind.

category:             Network, Web
abi:                  cb510bc9432703ca1452ec24608809b2
exposed:              True
exposed-modules:
    Program.Mighty Program.Mighty.ByteString Program.Mighty.Config
    Program.Mighty.Dhall.Option Program.Mighty.Network
    Program.Mighty.Parser Program.Mighty.Process Program.Mighty.Report
    Program.Mighty.Resource Program.Mighty.Route Program.Mighty.Signal
    Program.Mighty.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/mighttpd2-4.0.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/mighttpd2-4.0.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/mighttpd2-4.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/mighttpd2
hs-libraries:         HSmighttpd2-4.0.3-AVhNDiUT1EPDmWRHoMGzfH
depends:
    array-0.5.4.0 async-2.2.5-LqkzH7L8HyYHud0cQFVYjz
    auto-update-0.1.6-9I0nptitzgj4nyG03C8kv4 base-4.17.2.1
    byteorder-1.0.4-GnZZPnCtMLjHLa4McP5dl3 bytestring-0.11.5.3
    case-insensitive-1.2.1.0-6fVgEt7vrFc1sDHTeWeWXd
    conduit-1.3.6.1-8EwOhhDv3r5EX0bCaWMPRW
    conduit-extra-1.3.8-5wj2QtagE3YHzOewcAu6yq
    dhall-1.42.2-5IEoMzQ3a2VDosd7HjnVt2 directory-1.3.7.1
    filepath-1.4.2.2 http-date-0.0.11-FSxQ4oPmHYfF6UAAvZLcTq
    http-types-0.12.4-ALPJWcgMeIc83stb9QW9Gl
    network-3.1.4.0-9ZkyLgutzTZFWrHs4BgIgX parsec-3.1.16.1
    resourcet-1.2.6-1DDiq5XD7CWDw9CwnQya4j
    split-0.2.5-HF22Q1cIKmoK4fHDRbSUwV
    streaming-commons-0.2.3.0-GROQORqjjU1AlDKJpV35uv text-2.0.2
    unix-2.7.3 unix-time-0.4.17-7bCvFEsgm4i7S3bC9lRcF0
    unliftio-0.2.25.1-HM0R1ty4e2TDt6fGDzBedX
    unordered-containers-0.2.20-7dvM9aaOf5JATet72j0BPX
    wai-3.2.4-1yop7BvplydTH1djBo1do
    wai-app-file-cgi-3.1.10-4ZtbBzFKiiIG8MbQOOzzAQ
    warp-3.3.30-8OpZYlaRw56DjKQnzqAXnQ

haddock-interfaces:   /usr/share/doc/mighttpd2/html/mighttpd2.haddock
haddock-html:         /usr/share/doc/mighttpd2/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> mighttpd2-4.0.3-324-x86_64.pkg.tar.zst: usr/share/haskell/register/mighttpd2.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 mighttpd2
version:              4.0.3
visibility:           public
id:                   mighttpd2-4.0.3-CvBDkBtZiv8BaF2pYRUwVT
key:                  mighttpd2-4.0.3-CvBDkBtZiv8BaF2pYRUwVT
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
homepage:             https://kazu-yamamoto.github.io/mighttpd2/
synopsis:             High performance web server on WAI/warp
description:
    High performance web server to handle static
    files and CGI on WAI/warp.
    Reverse proxy functionality is also provided
    to connect web applications behind.

category:             Network, Web
abi:                  901d6b90d6202e655a8cd30c7f5ca549
exposed:              True
exposed-modules:
    Program.Mighty Program.Mighty.ByteString Program.Mighty.Config
    Program.Mighty.Dhall.Option Program.Mighty.Network
    Program.Mighty.Parser Program.Mighty.Process Program.Mighty.Report
    Program.Mighty.Resource Program.Mighty.Route Program.Mighty.Signal
    Program.Mighty.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/mighttpd2-4.0.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/mighttpd2-4.0.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/mighttpd2-4.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/mighttpd2
hs-libraries:         HSmighttpd2-4.0.3-CvBDkBtZiv8BaF2pYRUwVT
depends:
    array-0.5.4.0 async-2.2.5-LqkzH7L8HyYHud0cQFVYjz
    auto-update-0.1.6-9I0nptitzgj4nyG03C8kv4 base-4.17.2.1
    byteorder-1.0.4-GnZZPnCtMLjHLa4McP5dl3 bytestring-0.11.5.3
    case-insensitive-1.2.1.0-6fVgEt7vrFc1sDHTeWeWXd
    conduit-1.3.6.1-8EwOhhDv3r5EX0bCaWMPRW
    conduit-extra-1.3.8-5wj2QtagE3YHzOewcAu6yq
    dhall-1.42.2-DPwuaktESnbDzHLJwBm64E directory-1.3.7.1
    filepath-1.4.2.2 http-date-0.0.11-FSxQ4oPmHYfF6UAAvZLcTq
    http-types-0.12.4-ALPJWcgMeIc83stb9QW9Gl
    network-3.1.4.0-9ZkyLgutzTZFWrHs4BgIgX parsec-3.1.16.1
    resourcet-1.2.6-1DDiq5XD7CWDw9CwnQya4j
    split-0.2.5-HF22Q1cIKmoK4fHDRbSUwV
    streaming-commons-0.2.3.0-GROQORqjjU1AlDKJpV35uv text-2.0.2
    unix-2.7.3 unix-time-0.4.17-7bCvFEsgm4i7S3bC9lRcF0
    unliftio-0.2.25.1-HM0R1ty4e2TDt6fGDzBedX
    unordered-containers-0.2.20-7dvM9aaOf5JATet72j0BPX
    wai-3.2.4-1yop7BvplydTH1djBo1do
    wai-app-file-cgi-3.1.10-4ZtbBzFKiiIG8MbQOOzzAQ
    warp-3.3.30-8OpZYlaRw56DjKQnzqAXnQ

haddock-interfaces:   /usr/share/doc/mighttpd2/html/mighttpd2.haddock
haddock-html:         /usr/share/doc/mighttpd2/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
